@@ -1,3 +1,6 @@
+#' @rdname unf
+#' @importFrom stats is.ts
+#' @export
 unf5 <- 
 function(x, 
          digits = 7L, 
@@ -12,70 +15,81 @@ function(x,
          date_format = "%Y-%m-%d",
          decimal_seconds = 5,
          ...){
-    if(!truncation %in% c(128,192,196,256))
+    if (!truncation %in% c(128,192,196,256)) {
         stop("'truncation' must be in 128, 192, 196, 256")
-    if(truncation < characters)
+    }
+    if (truncation < characters) {
         stop("'truncation' must be greater than or equal to 'characters'")
-    if(inherits(x, 'AsIs')){
+    }
+    if (inherits(x, 'AsIs')) {
         x <- as.character(x)
     }
-    if(inherits(x, 'ts') | inherits(x, 'zoo') | inherits(x, 'difftime')) {
+    if (inherits(x, 'ts') | inherits(x, 'zoo') | inherits(x, 'difftime')) {
         x <- as.numeric(x)
     }
-    if(is.factor(x)) {
+    if (is.factor(x)) {
         # FACTOR: treat factor as character and truncate to k
-        if(factor_as_character)
+        if (factor_as_character) {
             x <- as.character(x)
-        else
+        } else {
             x <- as.numeric(x)
+        }
     }
-    if(is.complex(x)){
+    if (is.complex(x)) {
         # COMPLEX numbers: treat as character?
         x <- as.character(x)
         warning("Complex vector converted to character")
     }
-    if(is.raw(x)){
-        if(raw_as_character) # DVN ingests raw as character
+    if (is.raw(x)) {
+        if (raw_as_character) {
+            # Dataverse ingests raw as character
             x <- as.character(x)
-        # BIT: Normalize bit fields by converting to big-endian form, truncating all leading empty bits, aligning to a byte boundary by re-padding with leading zero bits, and base64 encoding to form a character string representation.
-        else {
-            char <- sapply(x, function(i){
+        } else {
+            # BIT: Normalize bit fields by converting to big-endian form, truncating all leading empty bits, aligning to a byte boundary by re-padding with leading zero bits, and base64 encoding to form a character string representation.
+            char <- sapply(x, function(i) {
                 r <- raw()
                 as.character(writeBin(i, r, endian='big'))
             })
             warning('UNF is untested on raw vectors')
         }
     }
-    if(inherits(x, 'Date')){
+    if (inherits(x, 'Date')) {
         # DATE:
         # Normalize time and date, based on a single, unambiguous representation selected from the many described in the ISO 8601 standard.
         # Convert calendar dates to a character string of the form YYYY-MM-DD. Partial dates in the form YYYY or YYYY-MM are permitted.
         # https://redmine.hmdc.harvard.edu/issues/2997
-        if(!date_format %in% c('%Y-%m-%d', '%Y-%m', '%Y', '%F'))
+        if (!date_format %in% c('%Y-%m-%d', '%Y-%m', '%Y', '%F')) {
             stop("'date_format' must be '%Y-%m-%d', '%Y-%m', '%Y', or '%F'")
+        }
         char <- format(x, fmt = date_format)
-    } else if(inherits(x, 'POSIXt')){
+    } else if (inherits(x, 'POSIXt')) {
         # DATE-TIME: Time representation is based on the ISO 8601 extended format, hh:mm:ss.fffff. When .fffff represents fractions of a second, it must contain no trailing (non-significant) zeroes, and is omitted if valued at zero. Other fractional representations, such as fractional minutes and hours, are not permitted. If the time zone of the observation is known, convert the time value to the UTC time zone and append a "Z" to the time representation.
-        if(inherits(x, 'POSIXlt'))
+        if (inherits(x, 'POSIXlt')) {
             x <- as.POSIXct(x)
+        }
         char <- paste0(format(x, "%Y-%m-%dT%H:%M:", timezone), 
                        gsub("\\.?0+$","",format(x, paste0("%OS",decimal_seconds), timezone)), 
                        ifelse(timezone=="UTC", "Z", ""))
-    } else if(is.character(x)){
+    } else if (is.character(x)) {
         # CHARACTER
         char <- as.character(x)
-        if(empty_character_as_missing)
+        if (empty_character_as_missing) {
             char <- ifelse(x=='',NA,char)
-    } else if(is.numeric(x)){
+        }
+    } else if (is.numeric(x)) {
         # NUMERICS: round to nearest, ties to even (use `signif` or `signifz`)
         char <- .expform(signif(x, digits), digits-1)
-        if(dvn_zero)
-            char <- ifelse(x==0, '+0.e-6', char) # https://redmine.hmdc.harvard.edu/issues/3085
+        if (dvn_zero) {
+            # https://redmine.hmdc.harvard.edu/issues/3085
+            char <- ifelse(x==0, '+0.e-6', char)
+        }
     } else if(is.logical(x)){
         # LOGICAL: normalize boolean to 0, 1, or missing, then treat as numeric
         char <- .expform(as.integer(x), digits-1)
-        if(dvn_zero)
-            char <- ifelse(x, char, '+0.e-6') # https://redmine.hmdc.harvard.edu/issues/3085
+        if(dvn_zero) {
+            # https://redmine.hmdc.harvard.edu/issues/3085
+            char <- ifelse(x, char, '+0.e-6') 
+        }
     }
     
     # replace non-finite and missing values with NA
